<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is a proprietary licensed product. 
 * For more information see License.txt in the plugin folder.

 * ---
 * Copyright (c) 2018, Ebenezer Obasi
 * All rights reserved.
 * info@eobasi.com.

 * Redistribution and use in source and binary forms, with or without modification, are not permitted provided.

 * This plugin should be bought from the developer. For details contact info@eobasi.com.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * Data Access Object for `helpcenter_topic` table.
 *
 * @author Ebenezer Obasi <info@eobasi.com>
 * @package ow_plugins.helpcenter.bol
 * @since 1.0
 */
class HELPCENTER_BOL_TopicDao extends OW_BaseDao
{
    /**
     * Singleton instance.
     *
     * @var HELPCENTER_BOL_TopicDao
     */
    private static $classInstance;

    /**
     * Returns an instance of class (singleton pattern implementation).
     *
     * @return HELPCENTER_BOL_TopicDao
     */
	public static function getInstance()
	{
		if( self::$classInstance === null )
		{
			self::$classInstance = new self();
		}

		return self::$classInstance;
	}

    /**
     * Constructor.
     */
    protected function __construct()
    {
        parent::__construct();
    }

    /**
     * @see OW_BaseDao::getDtoClassName()
     *
     */
	public function getDtoClassName()
	{
		return 'HELPCENTER_BOL_Topic';
	}

    /**
     * @see OW_BaseDao::getTableName()
     *
     */
	public function getTableName()
	{
		return OW_DB_PREFIX . 'helpcenter_topic';
	}
	
    /**
     * Save topic and return topic ID
     *
     * @param integer $topic
     * @return integer
     */
	public function saveTopic( $topic )
	{
		$this->save( $topic );

		return $this->dbo->getInsertId();
	}
	
    /**
     * Returns topics by categoryId
     *
     * @param integer $categoryId
     * @return array
     */
	public function findCategoryTopics( $categoryId )
	{
		$example = new OW_Example();
		$example->andFieldEqual('category', $categoryId);
		
		return $this->findListByExample( $example );
	}
	
    /**
     * Returns topics by saerch term
     *
     * @param string $term
     * @param integer $count
     * @param integer $first
     * @return array
     */
	public function search( $term, $first = null, $count = null )
	{
		$limit = '';
		
		if( !empty( $first ) )
		{
			$limit = "LIMIT $first, $count";
		}
		
		$query = "SELECT * FROM {$this->getTableName()}
			WHERE `title` LIKE '%{$this->dbo->escapeString($term)}%'
				OR `body` LIKE '%{$this->dbo->escapeString($term)}%'
			$limit";
		
		return $this->dbo->queryForObjectList($query, $this->getDtoClassName());
	}
}