<?php

/**
 * This software is intended for use with Oxwall Free Community Software http://www.oxwall.org/ and is a proprietary licensed product. 
 * For more information see License.txt in the plugin folder.

 * ---
 * Copyright (c) 2018, Ebenezer Obasi
 * All rights reserved.
 * info@eobasi.com.

 * Redistribution and use in source and binary forms, with or without modification, are not permitted provided.

 * This plugin should be bought from the developer. For details contact info@eobasi.com.

 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
/**
 * @author Ebenezer Obasi <info@eobasi.com>
 * @package ow_plugins.helpcenter.classes
 * @since 1.0
 */
class HELPCENTER_CLASS_EventHandler
{
	public static $classInstance;
	
	public static function getInstance()
	{
		if( self::$classInstance === null )
		{
			self::$classInstance = new self();
		}
		
		return self::$classInstance;
	}
	
	public function __construct( )
	{		
		$this->lang = OW::getLanguage();
		$this->service = HELPCENTER_BOL_Service::getInstance();
	}
	
	public function init()
	{
		OW::getEventManager()->bind(OW_EventManager::ON_BEFORE_DOCUMENT_RENDER, array($this, 'addAdminMenu'));
	}
	
    public function addAdminMenu( OW_Event $e )
    {
		$attrs = OW::getRequestHandler()->getHandlerAttributes();
		$controller = $attrs[OW_RequestHandler::ATTRS_KEY_CTRL];
		$action = $attrs[OW_RequestHandler::ATTRS_KEY_ACTION];
		
		if ( !is_subclass_of($attrs[OW_RequestHandler::ATTRS_KEY_CTRL], "ADMIN_CTRL_Abstract"))
		{
			return;
		}
		
		$icon = OW::getPluginManager()->getPlugin('helpcenter')->getStaticUrl() . 'img/help_icon.svg';
		$menuItems = $this->service->getAdminMenu()->getMenuItems();
		$url = OW::getRouter()->urlForRoute('helpcenter_admin_index');
		
		$active = $controller == 'HELPCENTER_CTRL_Topic' ? 'active' : null;
		
		$html = "<div class='ow_admin_menu_item menu_helpcenter $active'>
			<a href='$url' class='ow_admin_menu_item_label'>Help Center</a>
			<div class='ow_admin_menu_arrow'></div>
			<ul class='ow_admin_submenu_hover'>
				<li class='ow_admin_submenu_title'>Help Center</li>";		
				foreach( $menuItems as $item )
				{
					$url = $item->getUrl();
					$label = $item->getLabel();
					$item->current = $item->getKey() == $action ? 'active' : '';
					
					$html .= "<li class='$item->current' ><a href='$url' >$label</a></li>";
				}
		$html .= "</ul></div>";
		
		if( !empty( $active ) )
		{
			$html .= "<ul class='ow_admin_submenu'><li class='ow_admin_submenu_title'>Help Center</li>";	
			
			foreach( $menuItems as $item )
			{
				$url = $item->getUrl();
				$label = $item->getLabel();
				$item->current = $item->getKey() == $action ? 'active' : '';
				
				$html .= "<li class='$item->current' ><a href='$url' >$label</a></li>";
			}
			
			$html .= "</ul>";
		}
		
		$script = '$(".ow_admin_menu .menu_appearance").before("'.UTIL_HtmlTag::escapeJs( $html ).'");';
		OW::getDocument()->addOnloadScript($script);

		OW::getDocument()->addStyleDeclaration("
			.ow_admin_menu_item.menu_helpcenter {
				background-image: url($icon);
			}
		");
		
		/*
		$renderer = OW_ViewRenderer::getInstance();
		
        $pageBody = $renderer->getAssignedVar('pageBody');
		$pageBody = str_replace('<div class="ow_admin_menu_item menu_settings">', $html.'<div class="ow_admin_menu_item menu_settings">', $pageBody);
		
		$renderer->clearAssignedVar( 'pageBody' );
		$renderer->assignVar( 'pageBody', $pageBody);
		OW::getDocument()->getMasterPage()->assign( 'pageBody', $pageBody);*/
    }
	
	private function urlPath( $url )
	{
		return trim(parse_url($url)['path'], '/');
	}
}